function [applgevid, p1, p2, p3]=F_Q()
% function [applgevid]=F_Q(vbprb, g_vals, allFI) calculate the approximate log evidence
% calculate the negative free energy of the hierarchical probit GLM.
%
% (C) P. Sykacek 2005
% new version: we now consider the KL divergence between the 
% prior and posterior over the indicator probabilities.
% combining systems:
% This latest version has to consider multiple systems. This
% reflects itself in a modified get_FI and a separate neg. KL
% term for each systems prior precision matrix.
% modification for global vbprb, g_vals and allFI in 2006 

global vbprb;
global g_vals;
global allFI;

if isempty(allFI)
    get_FI;
end

% for each system we first obtain the negative KL divergence between prior and Q over lambda
g=vbprb.g;
h=vbprb.h;
nsys=length(vbprb.sys);
p1=0;
for n=1:nsys
    g_p=vbprb.sys(n).g_p;
    h_p=vbprb.sys(n).h_p;
    d_max=length(g_p);
    p1=p1+d_max*g*log(h) - sum(g_p.*log(h_p)) - d_max * gammaln(g) + sum(gammaln(g_p))+...
        sum((psi(g_p)-log(h_p)) .* (g-g_p)) + sum(g_p./h_p.*(h_p-h));
end
prcnt=vbprb.i_Priocnt;
pocnt=vbprb.i_Postcnt;
% KL divergence between prior and Q over Pi (theta). 
p2=gammaln(sum(prcnt))-gammaln(sum(pocnt))+sum(gammaln(pocnt))-...
    sum(gammaln(prcnt))+sum((prcnt-pocnt).*(psi(pocnt)-psi(sum(pocnt))));
% data dependent term
p3=sum(log(sum(exp(allFI), 2)));
% result: add all together
applgevid=p1+p2+p3;