function [subsets, allsystrain, allsystest, alltrdx, alltsdx]=prep_msys(ifname, remna)
% function [subsets, allsystrain, allsystest, alltrdx, alltsdx]=prep_msys(ifname, remna)
% is used to load all data that we analyse w.r.t. a specific 
% system as a cell array.
% IN 
% ifname:   input file name that contains the experiment description.
% remna:    1 if we should remove nan labels from the dataset 
%           (in this case all non nan data is in allsystrain and 
%           allsystest is emplty.
%           if 0, all nan labeled samples are added to allsystest.
% OUT
% subsets:      aubset information that is checked to be identical for all files!
% allsystrain,
% allsystest:   cell arrays containing training and test data as 
%               described above.
% alltestdx:    indices of test samples on the original data.
%               this allows to plot the original ordering of those samples
%               which mighgt be required in time course analysis.
% 
% (C) P. Sykacek 2005
%
% ifname structure: All 4 entries must be provided before the function 
% switches to the next system. Inapropriate entries (e.g. like non existing test files)
% are kept empty (i.e. newline after the specifier as shown for the third system).
% trlabels:	1	nan	0	1	nan	1	0	1	nan
% trfname:	sytem_one_tr.mat
% tstfname:	system_one_ts.mat
% tstlabels:	nan	nan	1	1	nan	0	0	1
% tstlabels:	1	nan	1	nan	0	1		
% tstfname:	system_two_tst.mat
% trfname:	system_two_tr.mat
% trlabels:	1	nan	nan	0	1	0	1	1
% trfname:  system_three.mat
% trlabels: 1   1   0   0   1   0
% tstfname:
% tstlabels:
% ....
% each quadrupel generates a separate entry in allsystrain and allsysytest.

% read in file strcuture
[fstruc]=readdef(ifname);
nsys=length(fstruc);
for n=1:nsys
    [train]=sload(fstruc(n).trfnam, 'train');
    [this_subs]=sload(fstruc(n).trfnam, 'subsets');
    if n==1
        subsets=this_subs;
    else % checking validity of subset definition.
        nsubs=length(subsets);
        ntsub=length(this_subs);
        if nsubs~=ntsub
            error('subset definition mismatch - aborting');
        else
            for m=1:nsubs
                if any(subsets{m}~=this_subs{m})
                    error('subset definition mismatch - aborting');
                end
            end
        end
    end
    if n==1
        ncols=size(train, 2);
    else % check validity of training data
        if size(train, 2)~= ncols
            error('dataset does not match others - aborting');
        end
    end
    if ~isempty(fstruc(n).trlabels) % the labels can be omitted if the ones in the file are correct.
        if length(fstruc(n).trlabels)~=size(train, 1)
            error('dataset does not match label specification - aborting');
        end
        % checks went ok now we need to relabel the data and split into allsystrain and allsystest
        train(:, size(train, 2))=fstruc(n).trlabels;
    end
    % now we have the labeled data and we change labels to 0,1:
    minlbl=min(train(:,ncols));
    if minlbl>0
        train(:,ncols)=train(:,ncols)-minlbl;
    end
    idtran=find(~isnan(train(:, size(train, 2))));
    alltrdx{n}=idtran;
    if ~isempty(idtran)
        allsystrain{n}=train(idtran, :);
    else
        allsystrain{n}=[];
    end
    idtest=find(isnan(train(:, size(train, 2))));
    alltsdx{n}=idtest;
    if ~isempty(idtest) & ~remna
        allsystest{n}=train(idtest, :);
    else
        allsystest{n}=[];
    end
    % finally we add the test data if such are available
    if ~isempty(fstruc(n).tstfnam)
        [test]=sload(fstruc(n).tstfnam, 'test');
        if ~isempty(fstruc(n).tstlabels) % otherwise use original labels.
            if length(fstruc(n).tstabels)~=size(test, 1)
                error('dataset does not match label specification - aborting');
            end
            % checks went ok now we need to relabel the data and split into allsystrain and allsystest
            test(:, size(test, 2))=fstruc(n).tstlabels;
        end
        allsystest{n}=[allsystest{n}; test];
    end
end        