function [P_msr]=vbprb_getmdlprbs(doindP, skipcomp)
% function [P_msr]=vbprb_getmdlprbs(vbprb, doindP, skipcomp)
% obtains various subset mesures from vbprb.
% IN:
% vbpbr:    hierarchical GLM
% doindP:   if 1 - indicator probabilities for "use subset" if 0:
%           calculate measure accross subsets.
% skipcomp:if existing and 1 - skip the reference subset 
%           (otherwise the reference subset is included in both measures 
%           at the corresponding position of the subset in the original 
%           subsets vector..)
% OUT: 
% P_msr:    Probability measure according to definition.
%
% (C) P. Sykacek  2005
% mod 2006: global vbprb;
global vbprb;
if nargin < 2
    skipempty=0;
end
% indicator measure in favour of "subset" is the second row in allIgprobs. 
P_ind=vbprb.allIgprobs(2,:);
refpos=vbprb.refsubspos;
if ~skipcomp
    nind=length(P_ind);
    % note: refpos was removed. the correct probability is thus at
    % refpos and we need to take the original guys starting at refpos...
    P_ind=[P_ind([1:(refpos-1)]), 0.5, P_ind([refpos:nind])];
end
if ~doindP
    % new: calculate from allFI:
    allFI=vbprb.allFI;
    nI=size(allFI,1);
    nsubs=size(allFI,2);
    if ~skipcomp
        % see what we do above with P_ind: its the same here!
        allFI=[allFI(:,[1:(refpos-1)]),log(0.5)*ones(nI,1), allFI(:,[refpos:nsubs])];
    end
    dFI=allFI(2,:)-allFI(1,:);
    P_msr=zeros(size(dFI));
    nsubs=length(P_msr);
    for n=1:nsubs
        P_msr(n)=1/(1+sum(exp(dFI([1:(n-1),(n+1):nsubs])-dFI(n))));
    end
else
    P_msr=P_ind;
end