function [allP, allgtrg, alltrtrg]=vbprb_pred(alltest, Pthrs)
% function [allP, allgtrg, alltrtrg]=vbprb_pred(vbprb, alltest, Pthrs)
% predict probabilities for targets of test data.
%
% IN:
% vbprb:    updated variational Bayesian hierarchical probit GLM.
%           as provided by calls to vballgprb and vbprb_tran.
% alltest:  labeled test data (cell array for every system one).
% Pthrs:    upper threshold in cumulative Probability - predict from all
%           top rank genes below that threshold.
% OUT:
% all%{n} is empty if there was no test data for the corresponding system.
% allP:        posterior probabilities for class (cell array one entry per system)
% allgtrg:     predicted target (cell array one entry per system)
% alltrtrg:    true target. (cell array one entry per system)
%
% (C) P. Sykacek 2005
% combining systems:
% This new version needs to predict for every system. We do no longer require
% the predallmodel option since this was meant to allow adjusting predictions 
% after fusion.
% mod 2006: global vbprb;

global vbprb;

if nargin < 2
    Pthrs=1;
end
% first we obtain the (global) measure accross subsets.
% we get the measure across subsets including the reference model.
[P_msr]=vbprb_getmdlprbs(0, 0);
[cumP, ind]=probs2cumprobs(P_msr, 1);
cumP=flipud(cumP);
ind=flipud(ind);
idlast=min(find(cumP>=Pthrs));
% idx: these models are the ones we predict with
if ~isempty(idlast)
    idx=ind(1:idlast);
else
    idx=ind;
end
% P_wght: the corresponding model probabilities (weighting!)
P_wght=P_msr(idx);
P_wght=P_wght/sum(P_wght);
nsys=length(vbprb.sys);
% loop over systems
for sctr=1:nsys
    test=alltest{sctr};
    if ~isempty(test)
        ntcols=size(test,2);
        trtrg=test(:,ntcols);
        %if max(trtrg)==2
        %    trtrg=trtrg-1;
        %    test(:, ntcols)=trtrg;
        %end
        % loop over the subsets that have the largest nmax model probabilities
        P=P_wght(1)*vbprb_predone(sctr, idx(1), test);
        n=2;
        nmax=length(idx);
        while n <= nmax
            P=P+P_wght(n)*vbprb_predone(sctr, idx(n), test);
            n=n+1;
        end
        P=[P, 1-P];
        gtrg= P(:,2)>P(:,1);
        % and finally store for corresponsing system.
        allP{sctr}=P;
        allgtrg{sctr}=gtrg;
        alltrtrg{sctr}=trtrg;
    else
        allP{sctr}=[];
        allgtrg{sctr}=[];
        alltrtrg{sctr}=[];
    end
end